Index: remoting/host/remoting_me2me_host.cc |
diff --git a/remoting/host/remoting_me2me_host.cc b/remoting/host/remoting_me2me_host.cc |
index 3b52799358b3d5efce4bb59eebe38e322277e49d..11858f71a7c4f975d90124531937b9a984097f78 100644 |
--- a/remoting/host/remoting_me2me_host.cc |
+++ b/remoting/host/remoting_me2me_host.cc |
@@ -1558,8 +1558,8 @@ int HostProcessMain() { |
// single-threaded. |
net::EnableSSLServerSockets(); |
- // Ensures runtime specific CPU features are initialized. |
- media::InitializeCPUSpecificMediaFeatures(); |
+ // Ensures that media library and specific CPU features are initialized. |
+ media::InitializeMediaLibrary(); |
// Create the main message loop and start helper threads. |
base::MessageLoopForUI message_loop; |